@@ -392,6 +392,8 @@ class CutPlan:
             3. Device type - only have accel values for lhy devices
             4. Acceleration number (manual or automatic)
             5. Actual raster speed (adjusted if necessary from Op speed)
+        If choice between merged or separated is evenly balanced, we prefer merged
+        by adding a constant value of 50 (mils) to the margins.
         """
 
         # Determine raster direction(s)
@@ -411,8 +413,8 @@ class CutPlan:
             return dx, dy
 
         # set minimum margins otherwise
-        dx = 500 if h_sweep else 0
-        dy = 500 if v_sweep else 0
+        dx = 500 if h_sweep else 50
+        dy = 500 if v_sweep else 50
 
         # Get device and check for lhystudios
         try:
@@ -446,9 +448,9 @@ class CutPlan:
 
         # Calculate margins
         if h_sweep:
-            dx = max(dx, CutPlan.sweep_distance(speed, h_accel))
+            dx = max(dx, CutPlan.sweep_distance(speed, h_accel)) + 50
         if v_sweep:
-            dy = max(dy, CutPlan.sweep_distance(speed, v_accel))
+            dy = max(dy, CutPlan.sweep_distance(speed, v_accel)) + 50
 
         return dx, dy
 
@@ -475,6 +477,8 @@ class CutPlan:
             dx, dy = self.get_raster_margins(op.settings)
 
             def adjust_bbox(bbox):
+                if bbox is None:
+                    return None
                 x1, y1, x2, y2 = bbox
                 return x1 - dx, y1 - dy, x2 + dx, y2 + dy
 
@@ -936,8 +940,8 @@ class CutPlan:
             # Stay on path in same direction if gap <= 1/20" i.e. path not quite closed
             # Travel only if path is completely burned or gap > 1/20"
             if distance > 50:
-                closest = self.short_travel_cutcode_candidate(
-                    context, closest, curr, distance
+                closest, backwards = self.short_travel_cutcode_candidate(
+                    context, closest, backwards, curr, distance
                 )
 
             if closest is None:
@@ -990,7 +994,7 @@ class CutPlan:
         return ordered
 
     def short_travel_cutcode_candidate(
-        self, context: CutCode, closest: Any, curr: complex, distance: float
+        self, context: CutCode, closest: Any, backwards: Any, curr: complex, distance: float
     ) -> Any:
         complete_path = self.context.opt_complete_subpaths
         for cut in context.candidate(
@@ -1026,7 +1030,7 @@ class CutPlan:
                         break
                     distance = d
 
-        return closest
+        return closest, backwards
 
     def short_travel_cutcode_2opt(self, context: CutCode, passes: int = 50):
         """
