@@ -131,6 +131,7 @@ class AboutPanel(wx.Panel):
 class About(MWindow):
     def __init__(self, *args, **kwds):
         from platform import system as _sys
+
         super().__init__(
             480,
             360,
@@ -140,7 +141,7 @@ class About(MWindow):
             | wx.FRAME_FLOAT_ON_PARENT
             | wx.TAB_TRAVERSAL
             | (wx.RESIZE_BORDER if _sys() != "Darwin" else 0),
-            **kwds
+            **kwds,
         )
         self.panel = AboutPanel(self, wx.ID_ANY, context=self.context)
         _icon = wx.NullIcon
