@@ -452,10 +452,13 @@ class LaserRender:
         if bounds is None:
             return None
         xmin, ymin, xmax, ymax = bounds
-        xmax = ceil(xmax)
-        ymax = ceil(ymax)
-        xmin = floor(xmin)
-        ymin = floor(ymin)
+        try:
+            xmax = ceil(xmax)
+            ymax = ceil(ymax)
+            xmin = floor(xmin)
+            ymin = floor(ymin)
+        except ValueError:
+            return None
 
         image_width = int(xmax - xmin)
         if image_width == 0:
@@ -542,6 +545,8 @@ class LaserRender:
                 width, height, pil_data.convert("RGBA").tobytes()
             )
 
+        if "transparency" in pil_data.info:
+            pil_data = pil_data.convert("RGBA")
         try:
             # If transparent we paste 0 into the pil_data
             mask = pil_data.getchannel("A").point(lambda e: 255 - e)
