@@ -512,7 +512,9 @@ class CamInterfaceWidget(Widget):
             item = menu.Append(wx.ID_ANY, _("Reset Perspective"), "")
             self.cam.Bind(
                 wx.EVT_MENU,
-                lambda e: self.cam.setting("camera%d perspective reset\n" % self.cam.index),
+                lambda e: self.cam.setting(
+                    "camera%d perspective reset\n" % self.cam.index
+                ),
                 id=item.GetId(),
             )
             item = menu.Append(wx.ID_ANY, _("Reset Fisheye"), "")
@@ -527,8 +529,10 @@ class CamInterfaceWidget(Widget):
             item = sub_menu.Append(wx.ID_ANY, _("Set URI"), "")
             self.cam.Bind(
                 wx.EVT_MENU,
-                lambda e: self.cam.context.open("window/CameraURI", self.cam, index=self.cam.index),
-                id=item.GetId()
+                lambda e: self.cam.context.open(
+                    "window/CameraURI", self.cam, index=self.cam.index
+                ),
+                id=item.GetId(),
             )
 
             camera_setting = self.cam.context.get_context("camera")
@@ -631,9 +635,10 @@ class CamPerspectiveWidget(Widget):
                 if self.mid:
                     perspective[self.index][0] += space_pos[4]
                     perspective[self.index][1] += space_pos[5]
-                for w in self.parent:
-                    if isinstance(w, CamPerspectiveWidget):
-                        w.update()
+                if self.parent is not None:
+                    for w in self.parent:
+                        if isinstance(w, CamPerspectiveWidget):
+                            w.update()
                 self.cam.setting.perspective = repr(perspective)
                 self.cam.context.signal("refresh_scene", 1)
             return RESPONSE_CONSUME
@@ -682,9 +687,9 @@ class CamImageWidget(Widget):
 
 class CameraInterface(MWindow):
     def __init__(self, context, path, parent, index=0, **kwds):
-        if isinstance(index,str):
+        if isinstance(index, str):
             try:
-                index=int(index)
+                index = int(index)
             except ValueError:
                 pass
         if index is None:
@@ -767,7 +772,7 @@ class CameraURIPanel(wx.Panel):
         if index is None:
             index = 0
         self.index = index
-        assert(isinstance(self.index, int))
+        assert isinstance(self.index, int)
 
         self.list_uri = wx.ListCtrl(
             self, wx.ID_ANY, style=wx.LC_HRULES | wx.LC_REPORT | wx.LC_VRULES
