@@ -39,8 +39,10 @@ ORIENTATION_GRID = 0b00000100000000
 ORIENTATION_NO_BUFFER = 0b00001000000000
 BUFFER = 10.0
 
-# LINECOL = wx.Colour(0x7F, 0x7F, 0x7F)
-LINECOL = wx.Colour(0xA0, 0x7F, 0xA0)
+
+def str_to_color(value):
+    c = Color(value)
+    return c.alpha << 24 | c.bgr
 
 
 class ElementsWidget(Widget):
@@ -104,9 +106,13 @@ class SelectionWidget(Widget):
         self.last_angle = None
         self.start_angle = None
         self.elements = scene.context.elements
+        self.color_border = None
+        self.color_handle = None
+
         self.selection_pen = wx.Pen()
-        self.selection_pen.SetColour(LINECOL)
         self.selection_pen.SetStyle(wx.PENSTYLE_DOT)
+        self.handle_pen = wx.Pen()
+        self.handle_pen.SetStyle(wx.PENSTYLE_SOLID)
         self.save_width = None
         self.save_height = None
         self.tool = self.tool_translate
@@ -117,9 +123,27 @@ class SelectionWidget(Widget):
         self.tool_running = False
         self.arcsegment = None
         self.draw_border = True
+        self.set_colors()
+
+    def set_colors(self, default=False):
+        color_manipulation = "#A07FA0"
+        self.scene.context.setting(str, "color_manipulation", color_manipulation)
+        self.scene.context.setting(str, "color_manipulation_handles", color_manipulation)
+        if default:
+            self.scene.context.color_manipulation = color_manipulation
+            self.scene.context.color_manipulation_handles = color_manipulation
+        try:
+            color1 = wx.Colour(str_to_color(self.scene.context.color_manipulation))
+            self.selection_pen.SetColour(color1)
+            self.color_border = color1
+
+            color2 = wx.Colour(str_to_color(self.scene.context.color_manipulation_handles))
+            self.handle_pen.SetColour(color2)
+            self.color_handle = color2
+        except (ValueError, TypeError):
+            pass
 
     def hit(self):
-
         elements = self.elements
         bounds = elements.selected_area()
         if bounds is not None:
@@ -160,6 +184,13 @@ class SelectionWidget(Widget):
             self.clear()
             return HITCHAIN_DELEGATE
 
+    def signal(self, signal, *args, **kwargs):
+        """
+        Signal commands which draw the background and updates the grid when needed recalculate the lines
+        """
+        if signal == "theme":
+            self.set_colors(args[0])
+
     def contains(self, x, y=None):
         """
         Query as to whether the current point is contained within the current widget.
@@ -175,38 +206,45 @@ class SelectionWidget(Widget):
             self.selbox_wy = 10.0 / matrix.value_scale_y()
 
         checks = [[self.left, self.top, self.right, self.bottom]]
+        mid_x = (self.right + self.left) / 2
+        mid_y = (self.bottom + self.top) / 2
+        # Selection very small ? Relocate Handle
+        inner_wd_half = (self.right - self.left) / 2
+        inner_ht_half = (self.bottom - self.top) / 2
+        dx = abs(min(0, inner_wd_half - self.selbox_wx))
+        dy = abs(min(0, inner_ht_half - self.selbox_wy))
         # The 4 side handles
         if self.use_handle_size:
             checks.append(
                 [
-                    self.left - self.selbox_wx / 2,
-                    (self.top + self.bottom) / 2 - self.selbox_wy / 2,
+                    self.left - self.selbox_wx / 2 - dx,
+                    mid_y - self.selbox_wy / 2,
                     self.left,
-                    (self.top + self.bottom) / 2 + self.selbox_wy / 2,
+                    mid_y + self.selbox_wy / 2,
                 ]
             )
             checks.append(
                 [
                     self.right,
-                    (self.top + self.bottom) / 2 - self.selbox_wy / 2,
-                    self.right + self.selbox_wx / 2,
-                    (self.top + self.bottom) / 2 + self.selbox_wy / 2,
+                    mid_y - self.selbox_wy / 2,
+                    self.right + self.selbox_wx / 2 + dx,
+                    mid_y + self.selbox_wy / 2,
                 ]
             )
             checks.append(
                 [
-                    (self.left + self.right) / 2 - self.selbox_wx / 2,
-                    self.top - self.selbox_wy / 2,
-                    (self.left + self.right) / 2 + self.selbox_wx / 2,
+                    mid_x - self.selbox_wx / 2,
+                    self.top - self.selbox_wy / 2 - dy,
+                    mid_x + self.selbox_wx / 2,
                     self.top,
                 ]
             )
             checks.append(
                 [
-                    (self.left + self.right) / 2 - self.selbox_wx / 2,
+                    mid_x - self.selbox_wx / 2,
                     self.bottom,
-                    (self.left + self.right) / 2 + self.selbox_wx / 2,
-                    self.bottom + self.selbox_wy / 2,
+                    mid_x + self.selbox_wx / 2,
+                    self.bottom + self.selbox_wy / 2 + dy,
                 ]
             )
 
@@ -217,34 +255,34 @@ class SelectionWidget(Widget):
             h_factor = 0.5
         checks.append(
             [
-                self.left - h_factor * self.selbox_wx,
-                self.top - h_factor * self.selbox_wy,
-                self.left + h_factor * self.selbox_wx,
-                self.top + h_factor * self.selbox_wy,
+                self.left - h_factor * self.selbox_wx - dx,
+                self.top - h_factor * self.selbox_wy - dy,
+                self.left + h_factor * self.selbox_wx - dx,
+                self.top + h_factor * self.selbox_wy - dy,
             ]
         )
         checks.append(
             [
-                self.right - h_factor * self.selbox_wx,
-                self.top - h_factor * self.selbox_wy,
-                self.right + h_factor * self.selbox_wx,
-                self.top + h_factor * self.selbox_wy,
+                self.right - h_factor * self.selbox_wx + dx,
+                self.top - h_factor * self.selbox_wy - dy,
+                self.right + h_factor * self.selbox_wx + dx,
+                self.top + h_factor * self.selbox_wy - dy,
             ]
         )
         checks.append(
             [
-                self.left - h_factor * self.selbox_wx,
-                self.bottom - h_factor * self.selbox_wy,
-                self.left + h_factor * self.selbox_wx,
-                self.bottom + h_factor * self.selbox_wy,
+                self.left - h_factor * self.selbox_wx - dx,
+                self.bottom - h_factor * self.selbox_wy + dy,
+                self.left + h_factor * self.selbox_wx - dx,
+                self.bottom + h_factor * self.selbox_wy + dy,
             ]
         )
         checks.append(
             [
-                self.right - h_factor * self.selbox_wx,
-                self.bottom - h_factor * self.selbox_wy,
-                self.right + h_factor * self.selbox_wx,
-                self.bottom + h_factor * self.selbox_wy,
+                self.right - h_factor * self.selbox_wx + dx,
+                self.bottom - h_factor * self.selbox_wy + dy,
+                self.right + h_factor * self.selbox_wx + dx,
+                self.bottom + h_factor * self.selbox_wy + dy,
             ]
         )
         if self.use_handle_skew:
@@ -254,20 +292,20 @@ class SelectionWidget(Widget):
                     self.left
                     + 3 / 4 * (self.right - self.left)
                     - 1 / 3 * self.selbox_wx,
-                    self.bottom - 1 / 3 * self.selbox_wy,
+                    self.bottom - 1 / 3 * self.selbox_wy + dx,
                     self.left
                     + 3 / 4 * (self.right - self.left)
                     + 1 / 3 * self.selbox_wx,
-                    self.bottom + 1 / 3 * self.selbox_wy,
+                    self.bottom + 1 / 3 * self.selbox_wy + dx,
                 ]
             )
             checks.append(
                 [
-                    self.right - 1 / 3 * self.selbox_wx,
+                    self.right - 1 / 3 * self.selbox_wx + dx,
                     self.top
                     + 1 / 4 * (self.bottom - self.top)
                     - 1 / 3 * self.selbox_wy,
-                    self.right + 1 / 3 * self.selbox_wx,
+                    self.right + 1 / 3 * self.selbox_wx + dx,
                     self.top
                     + 1 / 4 * (self.bottom - self.top)
                     + 1 / 3 * self.selbox_wy,
@@ -386,7 +424,18 @@ class SelectionWidget(Widget):
                 ymax = self.bottom
                 xin = space_pos[0]
                 yin = space_pos[1]
-
+                mid_x = (self.right + self.left) / 2
+                mid_y = (self.bottom + self.top) / 2
+                # Selection very small ? Relocate Handle
+                inner_wd_half = (self.right - self.left) / 2
+                inner_ht_half = (self.bottom - self.top) / 2
+                dx = abs(min(0, inner_wd_half - self.selbox_wx))
+                dy = abs(min(0, inner_ht_half - self.selbox_wy))
+                # Correct position
+                xmin -= dx
+                xmax += dx
+                ymin -= dy
+                ymax += dy
                 # If there is at least on element in the selection with a lock status, then the only manipulation we allow is a move operation
                 for e in elements.elems(emphasized=True):
                     try:
@@ -411,10 +460,10 @@ class SelectionWidget(Widget):
                 # The centre for moving
                 checks = [
                     [
-                        (xmin + xmax) / 2 - center_size * self.selbox_wx,
-                        (ymin + ymax) / 2 - center_size * self.selbox_wy,
-                        (xmin + xmax) / 2 + center_size * self.selbox_wx,
-                        (ymin + ymax) / 2 + center_size * self.selbox_wy,
+                        mid_x - center_size * self.selbox_wx / 2,
+                        mid_y - center_size * self.selbox_wy / 2,
+                        mid_x + center_size * self.selbox_wx / 2,
+                        mid_y + center_size * self.selbox_wy / 2,
                         "move",
                     ]
                 ]
@@ -422,35 +471,35 @@ class SelectionWidget(Widget):
                 checks.append(
                     [
                         xmin - self.selbox_wx / 2,
-                        (ymin + ymax) / 2 - self.selbox_wy / 2,
+                        mid_y - self.selbox_wy / 2,
                         xmin + self.selbox_wx / 2,
-                        (ymin + ymax) / 2 + self.selbox_wy / 2,
+                        mid_y + self.selbox_wy / 2,
                         "size_l",
                     ]
                 )
                 checks.append(
                     [
                         xmax - self.selbox_wx / 2,
-                        (ymin + ymax) / 2 - self.selbox_wy / 2,
+                        mid_y - self.selbox_wy / 2,
                         xmax + self.selbox_wx / 2,
-                        (ymin + ymax) / 2 + self.selbox_wy / 2,
+                        mid_y + self.selbox_wy / 2,
                         "size_r",
                     ]
                 )
                 checks.append(
                     [
-                        (xmin + xmax) / 2 - self.selbox_wx / 2,
+                        mid_x - self.selbox_wx / 2,
                         ymin - self.selbox_wy / 2,
-                        (xmin + xmax) / 2 + self.selbox_wx / 2,
+                        mid_x + self.selbox_wx / 2,
                         ymin + self.selbox_wy / 2,
                         "size_t",
                     ]
                 )
                 checks.append(
                     [
-                        (xmin + xmax) / 2 - self.selbox_wx / 2,
+                        mid_x - self.selbox_wx / 2,
                         ymax - self.selbox_wy / 2,
-                        (xmin + xmax) / 2 + self.selbox_wx / 2,
+                        mid_x + self.selbox_wx / 2,
                         ymax + self.selbox_wy / 2,
                         "size_b",
                     ]
@@ -572,9 +621,9 @@ class SelectionWidget(Widget):
                     # The two skew handles
                     checks.append(
                         [
-                            xmin + 3 / 4 * (xmax - xmin) - 1 / 3 * self.selbox_wx,
+                            xmin + 3 / 2 * inner_wd_half - 1 / 3 * self.selbox_wx,
                             ymax - 1 / 3 * self.selbox_wy,
-                            xmin + 3 / 4 * (xmax - xmin) + 1 / 3 * self.selbox_wx,
+                            xmin + 3 / 2 * inner_wd_half + 1 / 3 * self.selbox_wx,
                             ymax + 1 / 3 * self.selbox_wy,
                             "skew_x",
                         ]
@@ -582,9 +631,9 @@ class SelectionWidget(Widget):
                     checks.append(
                         [
                             xmax - 1 / 3 * self.selbox_wx,
-                            ymin + 1 / 4 * (ymax - ymin) - 1 / 3 * self.selbox_wy,
+                            ymin + 1 / 2 * inner_ht_half - 1 / 3 * self.selbox_wy,
                             xmax + 1 / 3 * self.selbox_wx,
-                            ymin + 1 / 4 * (ymax - ymin) + 1 / 3 * self.selbox_wy,
+                            ymin + 1 / 2 * inner_ht_half + 1 / 3 * self.selbox_wy,
                             "skew_y",
                         ]
                     )
@@ -845,14 +894,26 @@ class SelectionWidget(Widget):
             scalex = 1
             scaley = 1
             if "n" in method:
-                scaley = (self.bottom - position[1]) / self.save_height
+                try:
+                    scaley = (self.bottom - position[1]) / self.save_height
+                except ZeroDivisionError:
+                    scaley = 1
             elif "s" in method:
-                scaley = (position[1] - self.top) / self.save_height
+                try:
+                    scaley = (position[1] - self.top) / self.save_height
+                except ZeroDivisionError:
+                    scaley = 1
 
             if "w" in method:
-                scalex = (self.right - position[0]) / self.save_width
+                try:
+                    scalex = (self.right - position[0]) / self.save_width
+                except ZeroDivisionError:
+                    scalex = 1
             elif "e" in method:
-                scalex = (position[0] - self.left) / self.save_width
+                try:
+                    scalex = (position[0] - self.left) / self.save_width
+                except ZeroDivisionError:
+                    scalex = 1
 
             if self.key_shift_pressed:  # Override uniform behaviour
                 unif = False
@@ -1026,12 +1087,27 @@ class SelectionWidget(Widget):
 
             # Improved code by tatarize to establish rotation angle
             current_angle = Point.angle(position[:2], (self.rotate_cx, self.rotate_cy))
+
             if self.last_angle is None:
                 self.last_angle = current_angle
                 self.start_angle = current_angle
+
+            # Update Rotation angle...
+            if self.key_shift_pressed:
+                # Only steps of 5 deg
+                desired_step = 5 * (math.tau / 360)
+                old_angle = current_angle - self.start_angle
+                new_angle = round(old_angle / desired_step) * desired_step
+                current_angle += new_angle - old_angle
+            elif self.key_control_pressed:
+                # Only steps of 15 deg
+                desired_step = 15 * (math.tau / 360)
+                old_angle = current_angle - self.start_angle
+                new_angle = round(old_angle / desired_step) * desired_step
+                current_angle += new_angle - old_angle
+
             delta_angle = current_angle - self.last_angle
             self.last_angle = current_angle
-            # Update Rotation angle...
             self.rotated_angle = current_angle - self.start_angle
 
             # Bring back to 'regular' radians
@@ -1106,62 +1182,85 @@ class SelectionWidget(Widget):
         ]
 
         if self.use_handle_rotate:
+            mid_x = (x0 + y1) / 2
+            mid_y = (y0 + y1) / 2
+            # Selection very small ? Relocate Handle
+            inner_wd_half = (x1 - x0) / 2
+            inner_ht_half = (y1 - y0) / 2
+            dx = abs(min(0, inner_wd_half - wdx))
+            dy = abs(min(0, inner_ht_half - wdy))
             for i in range(2):
                 for j in range(2):
                     if i == 0:
                         signx = +1
-                        xx = x0
+                        xx = x0 - dx
                     else:
                         signx = -1
-                        xx = x1
+                        xx = x1 + dx
                     if j == 0:
                         signy = +1
-                        yy = y0
+                        yy = y0 - dy
                     else:
                         signy = -1
-                        yy = y1
+                        yy = y1 + dy
 
                     segment = []
                     for idx in range(len(self.arcsegment)):
                         x = xx + signx * self.arcsegment[idx][0]
                         y = yy + signy * self.arcsegment[idx][1]
                         segment += [(x, y)]
-                    pen = wx.Pen(LINECOL, 2, wx.SOLID)
+                    pen = self.handle_pen
                     pen.SetWidth(0.75 * self.selection_pen.GetWidth())
-                    pen.SetStyle(wx.PENSTYLE_SOLID)
                     gc.SetPen(pen)
                     gc.StrokeLines(segment)
 
     def draw_handles(self, gc, wdx, wdy, x0, y0, x1, y1):
         corners = []
+        mid_x = (x0 + x1) / 2
+        mid_y = (y0 + y1) / 2
+        # Selection very small ? Relocate Handle
+        inner_wd_half = (x1 - x0) / 2
+        inner_ht_half = (y1 - y0) / 2
+        dx = abs(min(0, inner_wd_half - wdx))
+        dy = abs(min(0, inner_ht_half - wdy))
         if self.use_handle_size:
             corners += [
                 # corners
-                [x0 - wdx / 2, y0 - wdy / 2, wdx, wdy],
-                [x1 - wdx / 2, y0 - wdy / 2, wdx, wdy],
-                [x0 - wdx / 2, y1 - wdy / 2, wdx, wdy],
-                [x1 - wdx / 2, y1 - wdy / 2, wdx, wdy],
+                [x0 - wdx / 2 - dx, y0 - wdy / 2 - dy, wdx, wdy],
+                [x1 - wdx / 2 + dx, y0 - wdy / 2 - dy, wdx, wdy],
+                [x0 - wdx / 2 - dx, y1 - wdy / 2 + dy, wdx, wdy],
+                [x1 - wdx / 2 + dx, y1 - wdy / 2 + dy, wdx, wdy],
                 # Middle of sides
-                [x0 - wdx / 2, (y1 + y0) / 2 - wdy / 2, wdx, wdy],
-                [x1 - wdx / 2, (y1 + y0) / 2 - wdy / 2, wdx, wdy],
-                [(x0 + x1) / 2 - wdx / 2, y0 - wdy / 2, wdx, wdy],
-                [(x0 + x1) / 2 - wdx / 2, y1 - wdy / 2, wdx, wdy],
+                [x0 - wdx / 2 - dx, mid_y - wdy / 2, wdx, wdy],
+                [x1 - wdx / 2 + dx, mid_y - wdy / 2, wdx, wdy],
+                [mid_x - wdx / 2, y0 - wdy / 2 - dy, wdx, wdy],
+                [mid_x - wdx / 2, y1 - wdy / 2 + dy, wdx, wdy],
                 # Center
-                [(x0 + x1) / 2 - wdx / 2, (y1 + y0) / 2 - wdy / 2, wdx, wdy],
+                [mid_x - wdx / 2, mid_y - wdy / 2, wdx, wdy],
             ]
         # Skew
-        if self.use_handle_skew:
+        show_skew_x = self.use_handle_skew
+        show_skew_y = self.use_handle_skew
+        # Let's check whether there is enough room...
+        # Top and bottom handle are overlapping by 1/2, middle 1, skew 2/3
+        if 2 * inner_ht_half < (0.5 + 1 + 0.5 + 1) * wdy:
+            show_skew_y = False
+        if 2 * inner_wd_half < (0.5 + 1 + 0.5 + 1) * wdx:
+            show_skew_x = False
+
+        if show_skew_x:
             corners.append(
                 [
                     x0 + 3 / 4 * (x1 - x0) - wdx / 3,
-                    y1 - wdy / 3,
+                    y1 - wdy / 3 + dy,
                     2 / 3 * wdx,
                     2 / 3 * wdy,
                 ]
             )  # skew x
+        if show_skew_y:
             corners.append(
                 [
-                    x1 - wdx / 3,
+                    x1 - wdx / 3 + dy,
                     y0 + 1 / 4 * (y1 - y0) - wdy / 3,
                     2 / 3 * wdx,
                     2 / 3 * wdy,
@@ -1169,9 +1268,9 @@ class SelectionWidget(Widget):
             )  # skew y
 
         if len(corners) > 0:
-            pen = wx.Pen(LINECOL, 1, wx.SOLID)
-            pen.SetStyle(wx.PENSTYLE_SOLID)
-            brush = wx.Brush(LINECOL, wx.SOLID)
+
+            pen = self.handle_pen
+            brush = wx.Brush(self.color_handle, wx.SOLID)
             gc.SetPen(pen)
             gc.SetBrush(brush)
 
@@ -1222,7 +1321,7 @@ class SelectionWidget(Widget):
             except TypeError:
                 font = wx.Font(int(font_size), wx.SWISS, wx.NORMAL, wx.BOLD)
 
-            gc.SetFont(font, LINECOL)
+            gc.SetFont(font, self.color_border)
             gc.SetPen(self.selection_pen)
             x0, y0, x1, y1 = bounds
             center_x = (x0 + x1) / 2.0
@@ -1450,6 +1549,8 @@ class RectSelectWidget(Widget):
                 return RESPONSE_CHAIN
 
         elif event_type == "leftup":
+            if self.start_location is None:
+                return RESPONSE_CHAIN
             _ = self.scene.context._
             self.update_statusmsg(_("Status"))
             elements.validate_selected_area()
@@ -1800,8 +1901,19 @@ class GridWidget(Widget):
         self.grid = None
         self.background = None
         self.grid_line_pen = wx.Pen()
-        self.grid_line_pen.SetColour(wx.Colour(0xA0, 0xA0, 0xA0))
         self.grid_line_pen.SetWidth(1)
+        self.set_colors()
+
+    def set_colors(self, default=False):
+        color_grid = "#A0A0A0"
+        self.scene.context.setting(str, "color_grid", color_grid)
+        if default:
+            self.scene.context.color_grid = color_grid
+        try:
+            grid_color = wx.Colour(str_to_color(self.scene.context.color_grid))
+            self.grid_line_pen.SetColour(grid_color)
+        except (ValueError, TypeError):
+            pass
 
     def hit(self):
         return HITCHAIN_HIT
@@ -1867,8 +1979,9 @@ class GridWidget(Widget):
         """
         Draw the grid on the scene.
         """
+        context = self.scene.context
+
         if self.scene.context.draw_mode & DRAW_MODE_BACKGROUND == 0:
-            context = self.scene.context
             if context is not None:
                 bed_dim = context.root
                 wmils = bed_dim.bed_width * MILS_IN_MM
@@ -1914,6 +2027,8 @@ class GridWidget(Widget):
             self.grid = None
         elif signal == "background":
             self.background = args[0]
+        elif signal == "theme":
+            self.set_colors(args[0])
 
 
 class GuideWidget(Widget):
