@@ -8,7 +8,12 @@ import traceback
 from meerk40t.gui.wxmscene import SceneWindow
 
 try:
+    # According to https://docs.wxpython.org/wx.richtext.1moduleindex.html
+    # richtext needs to be imported before wx.App i.e. wxMeerK40t is instantiated
+    # so we are doing it here even though we do not refer to it in this file
+    # richtext is used for the Console panel.
     import wx
+    from wx import richtext
 except ImportError as e:
     from ..core.exceptions import Mk40tImportAbort
 
@@ -19,6 +24,7 @@ from ..main import APPLICATION_NAME, APPLICATION_VERSION
 from .about import About
 from .bufferview import BufferView
 from .configuration import Configuration
+from .consoleproperty import ConsoleProperty
 from .controller import Controller
 from .executejob import ExecuteJob
 from .file.fileoutput import FileOutput
@@ -32,7 +38,6 @@ from .lhystudios.lhystudiosdrivergui import LhystudiosDriverGui
 from .moshi.moshicontrollergui import MoshiControllerGui
 from .moshi.moshidrivergui import MoshiDriverGui
 from .notes import Notes
-from .consoleproperty import ConsoleProperty
 from .operationproperty import OperationProperty
 from .panes.camerapanel import CameraInterface
 from .panes.consolepanel import Console
@@ -67,6 +72,7 @@ GUI_START = True
 
 
 def plugin(kernel, lifecycle):
+    # pylint: disable=global-statement
     global GUI_START
     kernel_root = kernel.root
     if lifecycle == "console":
@@ -122,25 +128,31 @@ def plugin(kernel, lifecycle):
                     bool, "window/%s/open_on_start" % window, False
                 ):
                     if window_index is not None:
-                        kernel.console("window open -m {index} {window} {index}\n".format(index=window_index, window=window_name))
+                        kernel.console(
+                            "window open -m {index} {window} {index}\n".format(
+                                index=window_index, window=window_name
+                            )
+                        )
                     else:
-                        kernel.console("window open {window}\n".format(window=window_name))
+                        kernel.console(
+                            "window open {window}\n".format(window=window_name)
+                        )
             meerk40tgui.MainLoop()
 
 
 _ = wx.GetTranslation
 supported_languages = (
-    ("en", u"English", wx.LANGUAGE_ENGLISH),
-    ("it", u"italiano", wx.LANGUAGE_ITALIAN),
-    ("fr", u"français", wx.LANGUAGE_FRENCH),
-    ("de", u"Deutsch", wx.LANGUAGE_GERMAN),
-    ("es", u"español", wx.LANGUAGE_SPANISH),
-    ("zh", u"中文", wx.LANGUAGE_CHINESE),
-    ("hu", u"Magyar", wx.LANGUAGE_HUNGARIAN),
-    ("pt_PT", u"português", wx.LANGUAGE_PORTUGUESE),
-    ("pt_BR", u"português brasileiro", wx.LANGUAGE_PORTUGUESE_BRAZILIAN),
-    ("ja", u"日本", wx.LANGUAGE_JAPANESE),
-    ("nl", u"Nederlands", wx.LANGUAGE_DUTCH),
+    ("en", "English", wx.LANGUAGE_ENGLISH),
+    ("it", "italiano", wx.LANGUAGE_ITALIAN),
+    ("fr", "français", wx.LANGUAGE_FRENCH),
+    ("de", "Deutsch", wx.LANGUAGE_GERMAN),
+    ("es", "español", wx.LANGUAGE_SPANISH),
+    ("zh", "中文", wx.LANGUAGE_CHINESE),
+    ("hu", "Magyar", wx.LANGUAGE_HUNGARIAN),
+    ("pt_PT", "português", wx.LANGUAGE_PORTUGUESE),
+    ("pt_BR", "português brasileiro", wx.LANGUAGE_PORTUGUESE_BRAZILIAN),
+    ("ja", "日本", wx.LANGUAGE_JAPANESE),
+    ("nl", "Nederlands", wx.LANGUAGE_DUTCH),
 )
 
 
@@ -185,6 +197,9 @@ class wxMeerK40t(wx.App, Module):
 
         # App started add the except hook
         sys.excepthook = handleGUIException
+        wx.ToolTip.SetAutoPop(10000)
+        wx.ToolTip.SetDelay(100)
+        wx.ToolTip.SetReshow(0)
 
     def on_app_close(self, event=None):
         try:
@@ -196,6 +211,14 @@ class wxMeerK40t(wx.App, Module):
     def OnInit(self):
         return True
 
+    def InitLocale(self):
+        import sys
+
+        if sys.platform.startswith("win") and sys.version_info > (3, 8):
+            import locale
+
+            locale.setlocale(locale.LC_ALL, "C")
+
     def BringWindowToFront(self):
         try:  # it's possible for this event to come when the frame is closed
             self.GetTopWindow().Raise()
@@ -302,7 +325,6 @@ class wxMeerK40t(wx.App, Module):
                 path = kernel.get_context(path)
 
             if remainder is None:
-                channel(_("----------"))
                 channel(_("Loaded Windows in Context %s:") % str(context.path))
                 for i, name in enumerate(context.opened):
                     if not name.startswith("window"):
@@ -310,14 +332,16 @@ class wxMeerK40t(wx.App, Module):
                     module = context.opened[name]
                     channel(_("%d: %s as type of %s") % (i + 1, name, type(module)))
 
-                channel(_("----------"))
-                channel(_("Loaded Windows in Device %s:") % str(path.path))
+                channel("----------")
+                if path is context:
+                    return "window", path
+                channel(_("Loaded Windows in Path %s:") % str(path.path))
                 for i, name in enumerate(path.opened):
                     if not name.startswith("window"):
                         continue
                     module = path.opened[name]
                     channel(_("%d: %s as type of %s") % (i + 1, name, type(module)))
-                channel(_("----------"))
+                channel("----------")
             return "window", path
 
         @kernel.console_command(
@@ -380,7 +404,7 @@ class wxMeerK40t(wx.App, Module):
             source=None,
             multi=None,
             args=(),
-            **kwargs
+            **kwargs,
         ):
             path = data
             try:
@@ -429,14 +453,15 @@ class wxMeerK40t(wx.App, Module):
 
             def window_open(*a, **k):
                 path.open_as(window_uri, window_name, parent, *args)
+                channel(_("Window opened: {window}").format(window=window))
 
             def window_close(*a, **k):
                 path.close(window_name, *args)
+                channel(_("Window closed: {window}").format(window=window))
 
             if command == "open":
                 if window_uri in context.registered:
                     kernel.run_later(window_open, None)
-                    channel(_("Window opened: {window}").format(window=window))
                 else:
                     channel(_("No such window as %s" % window))
                     raise SyntaxError
@@ -448,7 +473,6 @@ class wxMeerK40t(wx.App, Module):
                         channel(_("Window closed: {window}").format(window=window))
                     except KeyError:
                         kernel.run_later(window_open, None)
-                        channel(_("Window opened: {window}").format(window=window))
                 else:
                     channel(_("No such window as %s" % window))
                     raise SyntaxError
@@ -510,6 +534,7 @@ class wxMeerK40t(wx.App, Module):
         kernel = context.kernel
 
         try:  # pyinstaller internal location
+            # pylint: disable=no-member
             _resource_path = os.path.join(sys._MEIPASS, "locale")
             wx.Locale.AddCatalogLookupPathPrefix(_resource_path)
         except Exception:
